@@ -1,5 +1,5 @@
 from logging import exception
-from dataManager import DataProvider as dPrvdr
+from FieldEmission.dataManager import DataProvider as dPrvdr
 import numpy as np
 import math
 
